filters:
  and:
    - file.folder == "{{ schema.entities.project }}"
views:
  - type: cards
    name: {{ content.project_board_view_name }}
    order:
      - file.name
      - {{ properties.customer }}
      - {{ properties.dealer }}
      - {{ properties.product }}
      - {{ properties.discount }}
      - {{ properties.amount }}
      - {{ properties.status }}
      - {{ properties.contract_date }}
    sort: []
    columnSize:
      file.name: 266
