---
{{ properties.status }}:
{{ properties.customer }}:
{{ properties.dealer }}:
{{ properties.link }}:
{{ properties.product }}:
{{ properties.category }}:
{{ properties.amount }}:
{{ properties.start_date }}:
{{ properties.report_date }}:
{{ properties.quotation_date }}:
{{ properties.contract_date }}:
{{ properties.payment_date }}:
{{ properties.shipment_date }}:
{{ properties.delivery_date }}:
{{ properties.invoice_date }}:
---

## {{ content.project_summary }}

> {{ content.project_description }}

- 

## {{ content.project_reference }}

| {{ content.project_document }} | {{ content.project_link }}|
| ---- | ---- |
| {{ content.project_quotation }} |      |
| {{ content.project_contract }} |      |
| {{ content.project_receipt }} |      |
| {{ content.project_delivery }} |      |
| {{ content.project_express }} |      |
| {{ content.project_invoice }} |      |
| {{ content.project_support }} |      |
