---
{{ properties.crmid }}:
{{ properties.organization }}:
{{ properties.alias }}:
{{ properties.address }}:
{{ properties.taxid }}:
{{ properties.bank }}:
{{ properties.account }}:
{{ properties.website }}:
{{ properties.discount }}:
{{ properties.contact }}:
---
