---
{{ properties.name }}: {{ sample.contact.name }}
{{ properties.nickname }}: {{ sample.contact.nickname }}
{{ properties.phone }}: {{ sample.contact.phone }}
{{ properties.email }}: {{ sample.contact.email }}
---
