---
{{ properties.crmid }}:
{{ properties.organization }}: {{ sample.customer.name }}
{{ properties.alias }}: 
    - {{ sample.customer.alias }}
{{ properties.address }}: 
{{ properties.taxid }}:
{{ properties.bank }}:
{{ properties.account }}:
{{ properties.website }}:
{{ properties.discount }}: {{ sample.customer.discount }}
{{ properties.contact }}: 
    - {{ sample.customer.contact }}
---
