---
{{ properties.status }}: {{ sample.project.status }}
{{ properties.customer }}: {{ sample.project.customer }}
{{ properties.dealer }}: {{ sample.project.dealer }}
{{ properties.link }}: {{ sample.project.link }}
{{ properties.product }}:
{{ properties.category }}:
{{ properties.amount }}: {{ sample.project.amount }}
{{ properties.start_date }}: {{ sample.project.start_date }}
{{ properties.report_date }}:
{{ properties.quotation_date }}:
{{ properties.contract_date }}: {{ sample.project.contract_date }}
{{ properties.payment_date }}:
{{ properties.shipment_date }}:
{{ properties.delivery_date }}:
{{ properties.invoice_date }}:
---

## {{ content.project_summary }}

> {{ content.project_description }}

- {{ sample.project.summary }}

## {{ content.project_reference }}

| {{ content.project_document }} | {{ content.project_link }}|
| ---- | ---- |
| {{ content.project_quotation }} | {{ sample.project.quotation }} |
| {{ content.project_contract }} | {{ sample.project.contract }} |
| {{ content.project_receipt }} |      |
| {{ content.project_delivery }} |      |
| {{ content.project_express }} | {{ sample.project.express }} |
| {{ content.project_invoice }} |      |
| {{ content.project_support }} |      |
